"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _classnames = _interopRequireDefault(require("classnames"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireWildcard(require("react"));

var _reactCustomScrollbars = _interopRequireDefault(require("react-custom-scrollbars"));

var _constants = require("../../global/constants");

var _makeStyles = _interopRequireDefault(require("../../styles/makeStyles"));

var _rail = _interopRequireDefault(require("../rail"));

var _slide = _interopRequireDefault(require("../../utils/slide"));

var _useMediaQuery = _interopRequireDefault(require("../../utils/useMediaQuery"));

var _withTheme = _interopRequireDefault(require("../../styles/withTheme"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var propTypes = {
  /**
   * The content of the FiltersRail
   */
  children: _propTypes["default"].node,

  /**
   * Override or extend the styles applied to FiltersRail.
   */
  classes: _propTypes["default"].shape({
    root: _propTypes["default"].string
  }),

  /**
   * Assign additional class names to FiltersRail.
   */
  className: _propTypes["default"].string,

  /**
   * Used for DOM testing. https://testing-library.com/docs/queries/bytestid/
   */
  dataTestId: _propTypes["default"].string,

  /**
   * The `id` of the FiltersRail.
   */
  id: _propTypes["default"].string,

  /**
   * If `true`, FiltersRail is open
   */
  isOpen: _propTypes["default"].bool,

  /**
   * If `true`, the children of the FiltersRail will be contained within a
   * `ScrollBar` from the React Custom Scrollbars package.
   */
  isScrollable: _propTypes["default"].bool,

  /**
   * Assigns styling to the FiltersRail dependant on
   * whether it is a child of the Page or Drawer component.
   */
  moduleType: _propTypes["default"].oneOf(['drawer', 'page']),

  /**
   * HC's theme.
   */
  theme: _propTypes["default"].shape({
    breakpoints: _propTypes["default"].shape({
      only: _propTypes["default"].func
    })
  }).isRequired
};
var defaultProps = {
  children: undefined,
  classes: undefined,
  className: undefined,
  dataTestId: "".concat(_constants.UI_CLASS_NAME, "-fitlers_rail"),
  id: undefined,
  isOpen: undefined,
  isScrollable: false,
  moduleType: 'page'
};
var useStyles = (0, _makeStyles["default"])(function (theme) {
  var _$isOpen;

  var railWidth = 250;
  return {
    innerContainer: {
      minHeight: '100%',
      overflow: 'hidden',
      pointerEvents: 'auto',
      position: 'relative',
      zIndex: 1,
      '&::after': {
        zIndex: -1
      },
      '&$isOpen': {
        overflow: 'visible'
      },
      '&$isScrollable': {
        padding: [[0, 0, 0, theme.spacing(2)]]
      },
      '&$isNotScrollable': {
        height: 'auto'
      }
    },
    isInDrawer: {},
    isNotOpen: {},
    isNotInDrawer: {},
    isNotScrollable: {},
    isOpen: {},
    isScrollable: {},
    root: {
      pointerEvents: 'none',
      position: 'absolute',
      width: railWidth,
      zIndex: 1,
      '&$isInDrawer': {},
      '&$isNotInDrawer': {
        marginLeft: -theme.gutters.page[496],
        minHeight: '100%'
      },
      '& > span': {
        minHeight: '100%'
      },
      '&$isOpen': (_$isOpen = {}, _defineProperty(_$isOpen, "& + .".concat(_constants.BEM_CONTENT), {
        overflow: 'auto',
        transition: "margin ".concat(theme.transitions.create('', {
          duration: theme.transitions.duration["short"]
        }))
      }), _defineProperty(_$isOpen, "&$isNotInDrawer + .".concat(_constants.BEM_CONTENT), {
        marginLeft: railWidth - theme.gutters.page[496]
      }), _defineProperty(_$isOpen, "&$isInDrawer + .".concat(_constants.BEM_CONTENT), {
        marginLeft: railWidth
      }), _$isOpen)
    },
    scrollableChildrenContainer: {
      padding: [[theme.spacing(3), theme.spacing(2), theme.spacing(3), 0]],
      position: 'relative'
    }
  };
});

function FiltersRail(props) {
  var _ClassNames, _ClassNames2;

  var children = props.children,
      className = props.className,
      dataTestId = props.dataTestId,
      id = props.id,
      isOpen = props.isOpen,
      isScrollable = props.isScrollable,
      moduleType = props.moduleType,
      theme = props.theme;
  var filtersRailRef = (0, _react.useRef)();
  var classes = useStyles(props);
  var isMobile = (0, _useMediaQuery["default"])(theme.breakpoints.only('sm'));
  (0, _react.useEffect)(function () {
    if (!isMobile && filtersRailRef && filtersRailRef.current) {
      var filtersRailNode = filtersRailRef.current;
      var containerClassName = '.ui.page--container';
      var containerNode = filtersRailNode.closest(containerClassName);
      var containerOffsetTop = containerNode ? containerNode.offsetTop : 0;
      filtersRailNode.style.height = "calc(100% - ".concat(containerOffsetTop, "px)");
    }
  }, [isMobile]);

  if (isMobile) {
    return null;
  }

  var rootClasses = (0, _classnames["default"])(_constants.UI_CLASS_NAME, _constants.BEM_FILTERS_RAIL, classes.root, className, (_ClassNames = {}, _defineProperty(_ClassNames, classes.isInDrawer, moduleType === 'drawer'), _defineProperty(_ClassNames, classes.isOpen, isOpen), _defineProperty(_ClassNames, classes.isNotInDrawer, moduleType !== 'drawer'), _defineProperty(_ClassNames, classes.isNotOpen, !isOpen), _ClassNames));
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: rootClasses,
    "data-testid": dataTestId,
    id: id,
    ref: filtersRailRef
  }, /*#__PURE__*/_react["default"].createElement(_slide["default"], {
    direction: "right",
    "in": isOpen
  }, /*#__PURE__*/_react["default"].createElement(_rail["default"], {
    className: (0, _classnames["default"])(classes.innerContainer, (_ClassNames2 = {}, _defineProperty(_ClassNames2, classes.isOpen, isOpen), _defineProperty(_ClassNames2, classes.isScrollable, isScrollable), _defineProperty(_ClassNames2, classes.isNotScrollable, !isScrollable), _ClassNames2))
  }, isScrollable ? /*#__PURE__*/_react["default"].createElement(_reactCustomScrollbars["default"], {
    autoHide: true
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: classes.scrollableChildrenContainer
  }, children)) : children)));
}

FiltersRail.propTypes = propTypes;
FiltersRail.defaultProps = defaultProps;

var _default = (0, _withTheme["default"])(FiltersRail);

exports["default"] = _default;